==> org.opennms.features.telemetry.protocols.sflow.parser-25.0.0-20190307.220803-5-sources.jar: org/opennms/netmgt/telemetry/protocols/sflow/parser/proto/flows/BstDeviceBuffers.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.protocols.sflow.parser.proto.flows;

import java.nio.ByteBuffer;

import org.bson.BsonWriter;
import org.opennms.netmgt.telemetry.common.utils.BufferUtils;
import org.opennms.netmgt.telemetry.protocols.sflow.parser.InvalidPacketException;

import com.google.common.base.MoreObjects;

// struct bst_device_buffers {
//   int uc_pc;  /* unicast buffers percentage utilization */
//   int mc_pc;  /* multicast buffers percentage utilization */
// };

public class BstDeviceBuffers implements CounterData {
    public final Integer uc_pc;
    public final Integer mc_pc;

    public BstDeviceBuffers(final ByteBuffer buffer) throws InvalidPacketException {
        this.uc_pc = BufferUtils.sint32(buffer);
        this.mc_pc = BufferUtils.sint32(buffer);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("uc_pc", this.uc_pc)
                .add("mc_pc", this.mc_pc)
                .toString();
    }

    @Override
    public void writeBson(final BsonWriter bsonWriter) {
        bsonWriter.writeStartDocument();
        bsonWriter.writeInt32("uc_pc", this.uc_pc);
        bsonWriter.writeInt32("mc_pc", this.mc_pc);
        bsonWriter.writeEndDocument();
    }
}

==> org.opennms.features.telemetry.protocols.sflow.parser-25.0.0-20191127.035113-141-sources.jar: org/opennms/netmgt/telemetry/protocols/sflow/parser/proto/flows/BstDeviceBuffers.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.protocols.sflow.parser.proto.flows;

import java.nio.ByteBuffer;

import org.bson.BsonWriter;
import org.opennms.netmgt.telemetry.common.utils.BufferUtils;
import org.opennms.netmgt.telemetry.protocols.sflow.parser.SampleDatagramEnrichment;
import org.opennms.netmgt.telemetry.protocols.sflow.parser.InvalidPacketException;

import com.google.common.base.MoreObjects;

// struct bst_device_buffers {
//   int uc_pc;  /* unicast buffers percentage utilization */
//   int mc_pc;  /* multicast buffers percentage utilization */
// };

public class BstDeviceBuffers implements CounterData {
    public final Integer uc_pc;
    public final Integer mc_pc;

    public BstDeviceBuffers(final ByteBuffer buffer) throws InvalidPacketException {
        this.uc_pc = BufferUtils.sint32(buffer);
        this.mc_pc = BufferUtils.sint32(buffer);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add("uc_pc", this.uc_pc)
                .add("mc_pc", this.mc_pc)
                .toString();
    }

    @Override
    public void writeBson(final BsonWriter bsonWriter, final SampleDatagramEnrichment enr) {
        bsonWriter.writeStartDocument();
        bsonWriter.writeInt32("uc_pc", this.uc_pc);
        bsonWriter.writeInt32("mc_pc", this.mc_pc);
        bsonWriter.writeEndDocument();
    }
}
